@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -16,9 +16,7 @@ FilterActionExecTest::FilterActionExecTest(QObject *parent)
 {
 }
 
-FilterActionExecTest::~FilterActionExecTest()
-{
-}
+FilterActionExecTest::~FilterActionExecTest() = default;
 
 void FilterActionExecTest::shouldHaveDefaultValue()
 {
