@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -17,18 +17,18 @@ public:
     {
     }
 
-    bool matches(const Akonadi::Item &item) const override
+    Q_REQUIRED_RESULT bool matches(const Akonadi::Item &item) const override
     {
-        Q_UNUSED(item);
+        Q_UNUSED(item)
         return false;
     }
 
-    bool isEmpty() const override
+    Q_REQUIRED_RESULT bool isEmpty() const override
     {
         return false;
     }
 
-    MailCommon::SearchRule::RequiredPart requiredPart() const override
+    Q_REQUIRED_RESULT MailCommon::SearchRule::RequiredPart requiredPart() const override
     {
         return MailCommon::SearchRule::CompleteMessage;
     }
@@ -50,7 +50,7 @@ void SearchRuleTest::shouldHaveDefaultValue()
 void SearchRuleTest::shouldAssignValue()
 {
     TestSearchRule searchrule;
-    //TODO
+    // TODO
 }
 
 QTEST_MAIN(SearchRuleTest)
