@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,22 +10,22 @@
 #include <KDateComboBox>
 #include <KLocalizedString>
 
+#include <KLazyLocalizedString>
 #include <QComboBox>
 #include <QDate>
 #include <QObject>
 #include <QStackedWidget>
-
 using namespace MailCommon;
 
 static const struct {
     SearchRule::Function id;
-    const char *displayName;
-} DateFunctions[] = {{SearchRule::FuncEquals, I18N_NOOP("is equal to")},
-                     {SearchRule::FuncNotEqual, I18N_NOOP("is not equal to")},
-                     {SearchRule::FuncIsGreater, I18N_NOOP("is after")},
-                     {SearchRule::FuncIsLessOrEqual, I18N_NOOP("is before or equal to")},
-                     {SearchRule::FuncIsLess, I18N_NOOP("is before")},
-                     {SearchRule::FuncIsGreaterOrEqual, I18N_NOOP("is after or equal to")}};
+    const KLazyLocalizedString displayName;
+} DateFunctions[] = {{SearchRule::FuncEquals, kli18n("is equal to")},
+                     {SearchRule::FuncNotEqual, kli18n("is not equal to")},
+                     {SearchRule::FuncIsGreater, kli18n("is after")},
+                     {SearchRule::FuncIsLessOrEqual, kli18n("is before or equal to")},
+                     {SearchRule::FuncIsLess, kli18n("is before")},
+                     {SearchRule::FuncIsGreaterOrEqual, kli18n("is after or equal to")}};
 static const int DateFunctionCount = sizeof(DateFunctions) / sizeof(*DateFunctions);
 
 //---------------------------------------------------------------------------
@@ -40,7 +40,7 @@ QWidget *DateRuleWidgetHandler::createFunctionWidget(int number, QStackedWidget
     funcCombo->setMinimumWidth(50);
     funcCombo->setObjectName(QStringLiteral("dateRuleFuncCombo"));
     for (int i = 0; i < DateFunctionCount; ++i) {
-        funcCombo->addItem(i18n(DateFunctions[i].displayName));
+        funcCombo->addItem(DateFunctions[i].displayName.toString());
     }
     funcCombo->adjustSize();
     QObject::connect(funcCombo, SIGNAL(activated(int)), receiver, SLOT(slotFunctionChanged()));
@@ -96,7 +96,7 @@ QString DateRuleWidgetHandler::currentValue(const QStackedWidget *valueStack) co
         return dateInput->date().toString(Qt::ISODate);
     }
 
-    return QString();
+    return {};
 }
 
 //---------------------------------------------------------------------------
@@ -104,7 +104,7 @@ QString DateRuleWidgetHandler::currentValue(const QStackedWidget *valueStack) co
 QString DateRuleWidgetHandler::value(const QByteArray &field, const QStackedWidget *, const QStackedWidget *valueStack) const
 {
     if (!handlesField(field)) {
-        return QString();
+        return {};
     }
 
     return currentValue(valueStack);
@@ -115,7 +115,7 @@ QString DateRuleWidgetHandler::value(const QByteArray &field, const QStackedWidg
 QString DateRuleWidgetHandler::prettyValue(const QByteArray &field, const QStackedWidget *, const QStackedWidget *valueStack) const
 {
     if (!handlesField(field)) {
-        return QString();
+        return {};
     }
 
     return currentValue(valueStack);
