@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,47 +14,43 @@
 
 using namespace MailCommon;
 
+#include <KLazyLocalizedString>
 #include <QLabel>
 
 // also see SearchRule::matches() and SearchRule::Function
 // if you change the following strings!
 static const struct {
     SearchRule::Function id;
-    const char *displayName;
-} TextFunctions[] = {
-    { SearchRule::FuncContains, I18N_NOOP("contains")          },
-    { SearchRule::FuncContainsNot, I18N_NOOP("does not contain")   },
-    { SearchRule::FuncEquals, I18N_NOOP("equals")            },
-    { SearchRule::FuncNotEqual, I18N_NOOP("does not equal")     },
-    { SearchRule::FuncStartWith, I18N_NOOP("starts with")         },
-    { SearchRule::FuncNotStartWith, I18N_NOOP("does not start with")},
-    { SearchRule::FuncEndWith, I18N_NOOP("ends with")           },
-    { SearchRule::FuncNotEndWith, I18N_NOOP("does not end with")  },
+    const KLazyLocalizedString displayName;
+} TextFunctions[] = {{SearchRule::FuncContains, kli18n("contains")},
+                     {SearchRule::FuncContainsNot, kli18n("does not contain")},
+                     {SearchRule::FuncEquals, kli18n("equals")},
+                     {SearchRule::FuncNotEqual, kli18n("does not equal")},
+                     {SearchRule::FuncStartWith, kli18n("starts with")},
+                     {SearchRule::FuncNotStartWith, kli18n("does not start with")},
+                     {SearchRule::FuncEndWith, kli18n("ends with")},
+                     {SearchRule::FuncNotEndWith, kli18n("does not end with")},
 
-    { SearchRule::FuncRegExp, I18N_NOOP("matches regular expr.") },
-    { SearchRule::FuncNotRegExp, I18N_NOOP("does not match reg. expr.") }
-};
-static const int TextFunctionCount
-    = sizeof(TextFunctions) / sizeof(*TextFunctions);
+                     {SearchRule::FuncRegExp, kli18n("matches regular expr.")},
+                     {SearchRule::FuncNotRegExp, kli18n("does not match reg. expr.")}};
+static const int TextFunctionCount = sizeof(TextFunctions) / sizeof(*TextFunctions);
 
 //---------------------------------------------------------------------------
 
-QWidget *TextRuleWidgetHandler::createFunctionWidget(
-    int number, QStackedWidget *functionStack, const QObject *receiver, bool /*isBalooSearch*/) const
+QWidget *TextRuleWidgetHandler::createFunctionWidget(int number, QStackedWidget *functionStack, const QObject *receiver, bool /*isBalooSearch*/) const
 {
     if (number != 0) {
         return nullptr;
     }
 
-    auto *funcCombo = new QComboBox(functionStack);
+    auto funcCombo = new QComboBox(functionStack);
     funcCombo->setMinimumWidth(50);
     funcCombo->setObjectName(QStringLiteral("textRuleFuncCombo"));
     for (int i = 0; i < TextFunctionCount; ++i) {
-        funcCombo->addItem(i18n(TextFunctions[i].displayName));
+        funcCombo->addItem(TextFunctions[i].displayName.toString());
     }
     funcCombo->adjustSize();
-    QObject::connect(funcCombo, SIGNAL(activated(int)),
-                     receiver, SLOT(slotFunctionChanged()));
+    QObject::connect(funcCombo, SIGNAL(activated(int)), receiver, SLOT(slotFunctionChanged()));
     return funcCombo;
 }
 
@@ -63,20 +59,18 @@ QWidget *TextRuleWidgetHandler::createFunctionWidget(
 QWidget *TextRuleWidgetHandler::createValueWidget(int number, QStackedWidget *valueStack, const QObject *receiver) const
 {
     if (number == 0) {
-        auto *lineEdit = new KLineEdit(valueStack);
+        auto lineEdit = new KLineEdit(valueStack);
         lineEdit->setClearButtonEnabled(true);
         lineEdit->setTrapReturnKey(true);
         lineEdit->setObjectName(QStringLiteral("regExpLineEdit"));
-        QObject::connect(lineEdit, SIGNAL(textChanged(QString)),
-                         receiver, SLOT(slotValueChanged()));
-        QObject::connect(lineEdit, SIGNAL(returnPressed()),
-                         receiver, SLOT(slotReturnPressed()));
+        QObject::connect(lineEdit, SIGNAL(textChanged(QString)), receiver, SLOT(slotValueChanged()));
+        QObject::connect(lineEdit, SIGNAL(returnPressed()), receiver, SLOT(slotReturnPressed()));
         return lineEdit;
     }
 
     // blank QLabel to hide value widget for in-address-book rule
     if (number == 1) {
-        QLabel *label = new QLabel(valueStack);
+        auto label = new QLabel(valueStack);
         label->setObjectName(QStringLiteral("textRuleValueHider"));
         label->setBuddy(valueStack);
         return label;
@@ -86,8 +80,7 @@ QWidget *TextRuleWidgetHandler::createValueWidget(int number, QStackedWidget *va
 
 //---------------------------------------------------------------------------
 
-SearchRule::Function TextRuleWidgetHandler::currentFunction(
-    const QStackedWidget *functionStack) const
+SearchRule::Function TextRuleWidgetHandler::currentFunction(const QStackedWidget *functionStack) const
 {
     const auto funcCombo = functionStack->findChild<QComboBox *>(QStringLiteral("textRuleFuncCombo"));
 
@@ -109,7 +102,7 @@ SearchRule::Function TextRuleWidgetHandler::function(const QByteArray &, const Q
 
 QString TextRuleWidgetHandler::currentValue(const QStackedWidget *valueStack, SearchRule::Function) const
 {
-    //in other cases of func it is a lineedit
+    // in other cases of func it is a lineedit
     const KLineEdit *lineEdit = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
 
     if (lineEdit) {
@@ -117,7 +110,7 @@ QString TextRuleWidgetHandler::currentValue(const QStackedWidget *valueStack, Se
     }
 
     // or anything else, like addressbook
-    return QString();
+    return {};
 }
 
 //---------------------------------------------------------------------------
@@ -197,8 +190,7 @@ bool TextRuleWidgetHandler::setRule(QStackedWidget *functionStack, QStackedWidge
         funcCombo->blockSignals(false);
         functionStack->setCurrentWidget(funcCombo);
     }
-    auto *lineEdit
-        = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
+    auto *lineEdit = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
 
     if (lineEdit) {
         lineEdit->blockSignals(true);
@@ -220,12 +212,10 @@ bool TextRuleWidgetHandler::update(const QByteArray &, QStackedWidget *functionS
 
     // raise the correct value widget
     SearchRule::Function func = currentFunction(functionStack);
-    if (func == SearchRule::FuncIsInAddressbook
-        || func == SearchRule::FuncIsNotInAddressbook) {
+    if (func == SearchRule::FuncIsInAddressbook || func == SearchRule::FuncIsNotInAddressbook) {
         valueStack->setCurrentWidget(valueStack->findChild<QWidget *>(QStringLiteral("textRuleValueHider")));
     } else {
-        auto *lineEdit
-            = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
+        auto *lineEdit = valueStack->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
 
         if (lineEdit) {
             valueStack->setCurrentWidget(lineEdit);
